@@ -8,7 +8,7 @@
 
 package Log::Report::Message;
 use vars '$VERSION';
-$VERSION = '1.37';
+$VERSION = '1.38';
 
 
 use warnings;
@@ -113,6 +113,12 @@ sub to(;$)
 }
 
 
+sub errno(;$)
+{	my $self = shift;
+	@_ ? $self->{_errno} = shift : $self->{_errno};
+}
+
+
 sub valueOf($) { $_[0]->{$_[1]} }
 
 #--------------
